{% load i18n %}

<!-- active srp links tab -->
<div role="tabpanel" class="tab-pane fade in active" id="{{ tab_name }}">
    <div class="alert alert-info" role="alert">
        <div class="text-right srp-dashboard-total-isk-cost">
            {% translate "Total SRP Cost" %}:
            <span class="srp-dashboard-total-isk-cost-amount"></span>
        </div>
    </div>

    <div class="table-responsive">
        <table class="table table-striped table-aasrp table-srp-links" id="tab_aasrp_{{ tab_name }}" style="width: 100%;">
            <thead>
                <tr>
                    <th>{% translate "SRP Link Name" %}</th>
                    <th>{% translate "Creator" %}</th>
                    <th>{% translate "Fleet Time" %}</th>
                    <th>{% translate "Fleet Type" %}</th>
                    <th>{% translate "Doctrine" %}</th>
                    <th>{% translate "AAR" %}</th>
                    <th>{% translate "SRP Code" %}</th>
                    <th>{% translate "Fleet ISK Cost" %}</th>
                    <th>{% translate "Status" %}</th>
                    <th>{% translate "Requests" %}</th>
                    <th>{% translate "Actions" %}</th>
                </tr>
            </thead>
            <tbody></tbody>
        </table>
    </div>
</div>
