{% load bootstrap %}
{% load i18n %}

<!-- user settings tab -->
<div role="tabpanel" class="tab-pane fade" id="{{ tab_name }}">
    <div class="panel panel-default">
        <div class="panel-heading">
            <div class="panel-title">{% translate "Notification Settings" %}</div>
        </div>

        <div class="panel-body">
            <form autocomplete="off" action="{% url 'aasrp:dashboard' %}" method="post">
                {% csrf_token %}

                <fieldset class="aa-srp-request-form col-md-6 col-md-offset-3">
                    {{ user_settings_form|bootstrap }}

                    <div class="form-group aasrp-form-group text-right clearfix">
                        <button class="btn btn-primary" type="submit">
                            {% translate "Change Settings" %}
                        </button>
                    </div>
                </fieldset>
            </form>
        </div>
    </div>
</div>
