{% load i18n %}

<!-- remove request modal -->
<div class="modal fade" id="srp-request-remove" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="{% translate 'Close' %}">
                    <span aria-hidden="true">&times;</span>
                </button>

                <div class="modal-title">{% translate "Remove SRP Request" %}</div>
            </div>

            <div class="modal-body">
                <p>
                    {% translate "Are you sure you want to remove this SRP request?" %}
                </p>
            </div>

            <div class="modal-footer">
                <button id="modal-button-cancel-remove-request" type="button" class="btn btn-default btn-sm" data-dismiss="modal">
                    <i class="far fa-hand-paper"></i>
                    {% translate "Cancel" %}
                </button>
                <button id="modal-button-confirm-remove-request" type="button" class="btn btn-danger btn-sm" data-dismiss="modal">
                    <i class="fas fa-trash-alt"></i>
                    {% translate "Remove SRP Request" %}
                </button>
            </div>
        </div>
    </div>
</div>
